from kivy.app import App
from kivy.uix.widget import Widget
from kivy.uix.gridlayout import GridLayout
from kivy.graphics import Rectangle

from kivy.core.image import ImageLoader
from kivy.cache import Cache

imageloader = ImageLoader()
Cache.register('ctpug', limit=200)

def _load(filename):
   '''Load an object either from disk or from the cache.

      We rely on kivy's caching infrastructure'''
   obj = Cache.get('ctpug', filename)
   if obj is None:
       obj = imageloader.load(filename)
       Cache.append('ctpug', filename, obj)
   return obj.texture



class TileWidget(Widget):

    def __init__(self, filename):
        super(TileWidget, self).__init__(size=(64, 64))
        self.texture = _load(filename)
        with self.canvas:
            Rectangle(pos=self.pos, size=(64, 64), texture=self.texture)

    def on_touch_down(self, touch):
        if self.collide_point(*touch.pos):
            print 'Widget ', self.pos
            return True


class BackgroundWidget(GridLayout):

    def __init__(self):
        super(BackgroundWidget, self).__init__(cols=5, row_default_height=64)
        for row in range(5):
            for col in range(5):
                if (col + row) % 2:
                    widget = TileWidget('cwall.png')
                else:
                    widget = TileWidget('floor.png')

                self.add_widget(widget)
        

class DemoApp(App):

    def build(self):
        return BackgroundWidget()

if __name__ == "__main__":
    DemoApp().run()
